Module attacks

Module attacks 

Functions

bishop_attacks
init
Initialize all attack tables (magic and PEXT).
king_attacks
Return the attack bitboard for a king on the given square.
knight_attacks
Return the attack bitboard for a knight on the given square.
pawn_attacks
Return the attack bitboard for a pawn of the given color on the given square.
queen_attacks
rook_attacks