pub fn between_bb(s1: Square, s2: Square) -> BitboardExpand description
Return the bitboard of squares strictly between s1 and s2.
Returns Bitboard::EMPTY if the squares are not on the same rank,
file, or diagonal.
pub fn between_bb(s1: Square, s2: Square) -> BitboardReturn the bitboard of squares strictly between s1 and s2.
Returns Bitboard::EMPTY if the squares are not on the same rank,
file, or diagonal.