Functions
- bishop_
attacks - init
- Initialize all attack tables (magic and PEXT).
- king_
attacks - Return the attack bitboard for a king on the given square.
- knight_
attacks - Return the attack bitboard for a knight on the given square.
- pawn_
attacks - Return the attack bitboard for a pawn of the given color on the given square.
- queen_
attacks - rook_
attacks